==> clutter_0.1.0.orig.tar.gz: clutter-0.1.0/clutter/clutter-marshal.h <==

#ifndef __clutter_marshal_MARSHAL_H__
#define __clutter_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT64,INT64,FLOAT,BOOLEAN (./clutter-marshal.list:1) */
extern void clutter_marshal_VOID__INT64_INT64_FLOAT_BOOLEAN (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:STRING,BOOLEAN,BOOLEAN (./clutter-marshal.list:2) */
extern void clutter_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:INT (./clutter-marshal.list:3) */
#define clutter_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (./clutter-marshal.list:4) */
extern void clutter_marshal_VOID__INT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:BOXED (./clutter-marshal.list:5) */
#define clutter_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:OBJECT (./clutter-marshal.list:6) */
#define clutter_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:VOID (./clutter-marshal.list:7) */
#define clutter_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

G_END_DECLS

#endif /* __clutter_marshal_MARSHAL_H__ */

==> clutter_0.2.0.orig.tar.gz: clutter-0.2.0/clutter/clutter-marshal.h <==

#ifndef __clutter_marshal_MARSHAL_H__
#define __clutter_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT64,INT64,FLOAT,BOOLEAN (./clutter-marshal.list:1) */
extern void clutter_marshal_VOID__INT64_INT64_FLOAT_BOOLEAN (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:STRING,BOOLEAN,BOOLEAN (./clutter-marshal.list:2) */
extern void clutter_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:INT (./clutter-marshal.list:3) */
#define clutter_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (./clutter-marshal.list:4) */
extern void clutter_marshal_VOID__INT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:BOXED (./clutter-marshal.list:5) */
#define clutter_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:OBJECT (./clutter-marshal.list:6) */
#define clutter_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:VOID (./clutter-marshal.list:7) */
#define clutter_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:OBJECT,POINTER (./clutter-marshal.list:8) */
extern void clutter_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* __clutter_marshal_MARSHAL_H__ */
